==> presto-jdbc-0.78-sources.jar: com/facebook/presto/jdbc/PrestoIntervalYearMonth.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.jdbc;

import java.util.Objects;

public class PrestoIntervalYearMonth
{
    private final long months;

    public PrestoIntervalYearMonth(long months)
    {
        this.months = months;
    }

    public PrestoIntervalYearMonth(int year, int months)
    {
        this.months = (12 * year) + months;
    }

    public long getMonths()
    {
        return months;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(months);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        PrestoIntervalYearMonth other = (PrestoIntervalYearMonth) obj;
        return Objects.equals(this.months, other.months);
    }

    @Override
    public String toString()
    {
        return formatMonths(months);
    }

    private static String formatMonths(long months)
    {
        return (months / 12) + "-" + (months % 12);
    }
}

==> presto-jdbc-0.102-sources.jar: com/facebook/presto/jdbc/PrestoIntervalYearMonth.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.jdbc;

import java.util.Objects;

public class PrestoIntervalYearMonth
{
    private final long months;

    public PrestoIntervalYearMonth(long months)
    {
        this.months = months;
    }

    public PrestoIntervalYearMonth(int year, int months)
    {
        this.months = (12L * year) + months;
    }

    public long getMonths()
    {
        return months;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(months);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        PrestoIntervalYearMonth other = (PrestoIntervalYearMonth) obj;
        return Objects.equals(this.months, other.months);
    }

    @Override
    public String toString()
    {
        return formatMonths(months);
    }

    private static String formatMonths(long months)
    {
        return (months / 12) + "-" + (months % 12);
    }
}
